import { MotiPressableContext } from './context';
import type { MotiPressableInteractionProp } from './types';
declare type Factory = (containers: MotiPressableContext['containers']) => ReturnType<MotiPressableInteractionProp>;
/**
 * `useMotiPressables` lets you access the interaction state of *all* parent `MotiPressable` components.
 *
 * This offers more complex use-cases over `useMotiPressable`, which only lets you access the interaction state of a single parent `MotiPressable` at a time.
 *
 * Say you have a parent pressable, with a list of items:
 *
 * ```tsx
 * <MotiPressable id="list">
 *   {items.map(({ id }) => (
 *     <MotiPressable id={'item-' + id} key={id}>
 *       <Item id={id}  />
 *     </MotiPressable>
 *   )}
 * </MotiPressable>
 * ```
 *
 * Then, in your component, you can access each unique `MotiPressable`'s interaction state:
 *
 * ```tsx
 * const Item = ({ id }) => {
 *  const state = useMotiPressables((containers) => {
 *    'worklet'
 *
 *    const list = containers.list.value
 *    const item = containers.['item-' + id].value
 *
 *    // when hovering a list,
 *    // fade out all items except the one actually hovered
 *
 *    let opacity = 1
 *    if (item.hovered || item.pressed) {
 *      opacity = 1
 *    } else if (list.hovered) {
 *      opacity = 0.7
 *    }
 *
 *    return {
 *      opacity,
 *    }
 *  })
 *
 *  return <MotiView state={state} />
 * }
 * ```
 *
 * Example shown [here](https://twitter.com/FernandoTheRojo/status/1430717474778066944)
 *
 * <img height={300} width={400} src="https://pbs.twimg.com/media/E9rqA35XIAQmbuk?format=jpg&name=4096x4096" />
 */
export declare function useMotiPressables(
/**
 * Function that receives the interaction state from all parent containers and returns a style object/
 * @worklet
 */
factory: Factory, deps?: readonly any[]): {
    __state: Readonly<{
        value: {
            backfaceVisibility?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            backgroundColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderBottomColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderBottomEndRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderBottomLeftRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderBottomRightRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderBottomStartRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderBottomWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderEndColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderLeftColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderLeftWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderRightColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderRightWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderStartColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderStyle?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderTopColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderTopEndRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderTopLeftRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderTopRightRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderTopStartRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderTopWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            opacity?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            testID?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            elevation?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            alignContent?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            alignItems?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            alignSelf?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            aspectRatio?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderEndWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            borderStartWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            bottom?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            display?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            end?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            flex?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            flexBasis?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            flexDirection?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            flexGrow?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            flexShrink?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            flexWrap?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            height?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            justifyContent?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            left?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            margin?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            marginBottom?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            marginEnd?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            marginHorizontal?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            marginLeft?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            marginRight?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            marginStart?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            marginTop?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            marginVertical?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            maxHeight?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            maxWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            minHeight?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            minWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            overflow?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            padding?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            paddingBottom?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            paddingEnd?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            paddingHorizontal?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            paddingLeft?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            paddingRight?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            paddingStart?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            paddingTop?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            paddingVertical?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            position?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            right?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            start?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            top?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            width?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            zIndex?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            direction?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            shadowColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            shadowOffset?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            shadowOpacity?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            shadowRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            transformMatrix?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            rotation?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            scaleX?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            scaleY?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            translateX?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            translateY?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            perspective?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            rotate?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            rotateX?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            rotateY?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            rotateZ?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            scale?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            skewX?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            skewY?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                width: number;
                height: number;
            } | undefined>[] | {
                value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | undefined>;
            } | undefined;
            transform?: Partial<import("../..").StyleValueWithSequenceArraysWithoutTransform<import("../..").Transforms, "scaleX" | "scaleY" | "translateX" | "translateY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "rotateZ" | "scale" | "skewX" | "skewY", "scaleX" | "scaleY" | "translateX" | "translateY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "rotateZ" | "scale" | "skewX" | "skewY"> & import("../..").StyleValueWithSequenceArraysWithTransform>[] | {
                value: undefined;
                onDidAnimate: import("../..").InlineOnDidAnimate<Partial<import("../..").StyleValueWithSequenceArraysWithoutTransform<import("../..").Transforms, "scaleX" | "scaleY" | "translateX" | "translateY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "rotateZ" | "scale" | "skewX" | "skewY", "scaleX" | "scaleY" | "translateX" | "translateY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "rotateZ" | "scale" | "skewX" | "skewY"> & import("../..").StyleValueWithSequenceArraysWithTransform>[] | undefined>;
            } | undefined;
        } | Readonly<{
            value: {
                backfaceVisibility?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                backgroundColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderBottomColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderBottomEndRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderBottomLeftRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderBottomRightRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderBottomStartRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderBottomWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderEndColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderLeftColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderLeftWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderRightColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderRightWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderStartColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderStyle?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderTopColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderTopEndRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderTopLeftRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderTopRightRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderTopStartRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderTopWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                opacity?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                testID?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                elevation?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                alignContent?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                alignItems?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                alignSelf?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                aspectRatio?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderEndWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                borderStartWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                bottom?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                display?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                end?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                flex?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                flexBasis?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                flexDirection?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                flexGrow?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                flexShrink?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                flexWrap?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                height?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                justifyContent?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                left?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                margin?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                marginBottom?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                marginEnd?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                marginHorizontal?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                marginLeft?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                marginRight?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                marginStart?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                marginTop?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                marginVertical?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                maxHeight?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                maxWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                minHeight?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                minWidth?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                overflow?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                padding?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                paddingBottom?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                paddingEnd?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                paddingHorizontal?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                paddingLeft?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                paddingRight?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                paddingStart?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                paddingTop?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                paddingVertical?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                position?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                right?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                start?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                top?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                width?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                zIndex?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                direction?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                shadowColor?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                shadowOffset?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                shadowOpacity?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                shadowRadius?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                transformMatrix?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                rotation?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                scaleX?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                scaleY?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                translateX?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                translateY?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                perspective?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                rotate?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                rotateX?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                rotateY?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                rotateZ?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                scale?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                skewX?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                skewY?: string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                    width: number;
                    height: number;
                } | undefined>[] | {
                    value: string | number | typeof import("react-native").OpaqueColorValue | undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | import("../..").SequenceItem<string | number | typeof import("react-native").OpaqueColorValue | number[] | {
                        width: number;
                        height: number;
                    } | undefined>[] | undefined>;
                } | undefined;
                transform?: Partial<import("../..").StyleValueWithSequenceArraysWithoutTransform<import("../..").Transforms, "scaleX" | "scaleY" | "translateX" | "translateY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "rotateZ" | "scale" | "skewX" | "skewY", "scaleX" | "scaleY" | "translateX" | "translateY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "rotateZ" | "scale" | "skewX" | "skewY"> & import("../..").StyleValueWithSequenceArraysWithTransform>[] | {
                    value: undefined;
                    onDidAnimate: import("../..").InlineOnDidAnimate<Partial<import("../..").StyleValueWithSequenceArraysWithoutTransform<import("../..").Transforms, "scaleX" | "scaleY" | "translateX" | "translateY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "rotateZ" | "scale" | "skewX" | "skewY", "scaleX" | "scaleY" | "translateX" | "translateY" | "perspective" | "rotate" | "rotateX" | "rotateY" | "rotateZ" | "scale" | "skewX" | "skewY"> & import("../..").StyleValueWithSequenceArraysWithTransform>[] | undefined>;
                } | undefined;
            };
        }>;
    }>;
};
export {};
